# combo - content management system
# Copyright (C) 2014-2016  Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.conf import settings
from django.utils.translation import ugettext_lazy as _

from combo.data.models import CellBase
from combo.data.library import register_cell_class
from combo.utils import requests



@register_cell_class
class RecentDocumentsCell(CellBase):
    template_name = 'combo/fargo/recent-documents-cell.html'

    class Meta:
        verbose_name = _('Recent Documents')

    def is_visible(self, user=None):
        if not user or user.is_anonymous():
            return False
        return super(RecentDocumentsCell, self).is_visible(user)

    @classmethod
    def is_enabled(cls):
        return hasattr(settings, 'KNOWN_SERVICES') and settings.KNOWN_SERVICES.get('fargo')

    def get_json(self, path, context):
        response = requests.get(path,
                remote_service=settings.KNOWN_SERVICES['fargo'].values()[0],
                user=self.get_concerned_user(context),
                raise_if_not_cached=not(context.get('synchronous')),
                headers={'accept': 'application/json'})
        if response.status_code == 200:
            return response.json()
        return None

    def render(self, context):
        context.update(self.get_json('api/documents/recently-added', context))
        return super(RecentDocumentsCell, self).render(context)
